powered by
qj2max Interval Data conversion
qj2max(x, qlow, qup, i)
The Data that needs to be maximized.
An interval lower bound vector with interval numeric value forward,other types of indicators are marked as NA.
An interval upper bound vector of the interval value maximize,other types of indicators are marked as NA.
Index column.
Index column maximized